Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewChiRouter ¶
NewChiRouter creates a new Chi router with a set of middleware for request ID injection, structured logging, telemetry, and recovery.
func NewGRPCServer ¶
func NewGRPCServer(enableReflection bool, registerFunc ...RegistrationFunc) *grpc.Server
NewGRPCServer creates a new gRPC server instance with optional reflection and service registration.
func NewHTTPServer ¶
NewHTTPServer creates and configures a new HTTP server instance.
Types ¶
type HTTPConfig ¶
type HTTPConfig struct {
Port int
MaxHeaderBytes int
ReadTimeout time.Duration
WriteTimeout time.Duration
IdleTimeout time.Duration
ReadHeader time.Duration
}
HTTPConfig has the configuration for the HTTP server.
type RegistrationFunc ¶
RegistrationFunc registers a grpc service with the server.
Click to show internal directories.
Click to hide internal directories.